.. PyMend documentation master file, created by
   sphinx-quickstart on Thu Oct  5 21:00:54 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################################
Welcome to PyMend's documentation!
##################################

.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   getting_started
   usage_and_configuration/index
   guides/index
   faq



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
